import 'dart:io';
import 'dart:ui';

import 'package:device_info_plus/device_info_plus.dart';
import 'package:yourappname/firebase_options.dart';
import 'package:yourappname/model/download_item.dart';
import 'package:yourappname/model/downloadaudiobook.dart';
import 'package:yourappname/pages/musicdetails.dart';
import 'package:yourappname/pages/splash.dart';
import 'package:yourappname/provider/audiosectiondataprovider.dart';
import 'package:yourappname/provider/avatarprovider.dart';
import 'package:yourappname/provider/channelsectionprovider.dart';
import 'package:yourappname/provider/connectivityprovider.dart';
import 'package:yourappname/provider/downloadprovider.dart';
import 'package:yourappname/provider/musicdetailprovider.dart';
import 'package:yourappname/provider/musicprovider.dart';
import 'package:yourappname/provider/notificationprovider.dart';
import 'package:yourappname/provider/novelsectiondataprovider.dart';
import 'package:yourappname/provider/rewardprovider.dart';
import 'package:yourappname/provider/seallprovider.dart';
// import 'package:yourappname/provider/showdownloadprovider.dart';
import 'package:yourappname/provider/threadprovider.dart';
import 'package:yourappname/provider/episodeprovider.dart';
import 'package:yourappname/provider/findprovider.dart';
import 'package:yourappname/provider/generalprovider.dart';
import 'package:yourappname/provider/homeprovider.dart';
import 'package:yourappname/provider/paymentprovider.dart';
import 'package:yourappname/provider/playerprovider.dart';
import 'package:yourappname/provider/profileprovider.dart';
import 'package:yourappname/provider/searchprovider.dart';
import 'package:yourappname/provider/sectiondataprovider.dart';
import 'package:yourappname/provider/showdetailsprovider.dart';
import 'package:yourappname/provider/subscriptionprovider.dart';
import 'package:yourappname/provider/videobyidprovider.dart';
import 'package:yourappname/provider/videodetailsprovider.dart';
import 'package:yourappname/provider/watchlistprovider.dart';
import 'package:yourappname/routes/routes_config.dart';
import 'package:yourappname/utils/color.dart';
import 'package:yourappname/utils/constant.dart';
import 'package:yourappname/utils/musicmanager.dart';
import 'package:yourappname/utils/sharedpre.dart';
import 'package:yourappname/utils/utils.dart';
import 'package:firebase_core/firebase_core.dart';
import 'package:flutter/foundation.dart';
import 'package:flutter/material.dart';
import 'package:flutter/services.dart';
import 'package:flutter_locales/flutter_locales.dart';
import 'package:google_mobile_ads/google_mobile_ads.dart';
import 'package:hive/hive.dart';
import 'package:just_audio_background/just_audio_background.dart';
import 'package:path_provider/path_provider.dart';
import 'package:provider/provider.dart';
import 'package:responsive_framework/responsive_framework.dart';

Future<void> main() async {
  WidgetsFlutterBinding.ensureInitialized();

  await JustAudioBackground.init(
    androidNotificationChannelId: Constant.appPackageName,
    androidNotificationChannelName: Constant.appName,
    notificationColor: colorPrimaryDark,
    androidNotificationOngoing: true,
    androidShowNotificationBadge: true,
  );
  if (!kIsWeb) {
    await MobileAds.instance.initialize();
    /* Initialize Hive Start */
    final appDocumentDir = await getApplicationDocumentsDirectory();
    printLog("appDocumentDir Path ==> ${appDocumentDir.path}");
    Hive.init(appDocumentDir.path);
    Hive.registerAdapter(DownloadEpisodeItemAdapter());
    Hive.registerAdapter(AudioBookBoxAdapter());

    /* Initialize Hive End */
  }
  await Firebase.initializeApp(
    options: DefaultFirebaseOptions.currentPlatform,
  );
  await Locales.init([
    'en',
    'af',
    'ar',
    'de',
    'es',
    'fr',
    'gu',
    'hi',
    'id',
    'nl',
    'pt',
    'sq',
    'tr',
    'vi'
  ]);

  runApp(
    MultiProvider(
      providers: [
        ChangeNotifierProvider(create: (_) => ConnectivityProvider()),
        ChangeNotifierProvider(create: (_) => AvatarProvider()),
        ChangeNotifierProvider(create: (_) => ChannelSectionProvider()),
        ChangeNotifierProvider(create: (_) => EpisodeProvider()),
        ChangeNotifierProvider(create: (_) => FindProvider()),
        ChangeNotifierProvider(create: (_) => GeneralProvider()),
        ChangeNotifierProvider(create: (_) => HomeProvider()),
        ChangeNotifierProvider(create: (_) => PaymentProvider()),
        ChangeNotifierProvider(create: (_) => PlayerProvider()),
        ChangeNotifierProvider(create: (_) => ProfileProvider()),
        ChangeNotifierProvider(create: (_) => SearchProvider()),
        ChangeNotifierProvider(create: (_) => SectionDataProvider()),
        ChangeNotifierProvider(create: (_) => ShowDetailsProvider()),
        ChangeNotifierProvider(create: (_) => SubscriptionProvider()),
        ChangeNotifierProvider(create: (_) => VideoByIDProvider()),
        ChangeNotifierProvider(create: (_) => VideoDetailsProvider()),
        ChangeNotifierProvider(create: (_) => WatchlistProvider()),
        ChangeNotifierProvider(create: (_) => AudioSectionDataProvider()),
        ChangeNotifierProvider(create: (_) => NovelSectionDataProvider()),
        ChangeNotifierProvider(create: (_) => ThreadProvider()),
        ChangeNotifierProvider(create: (_) => SeeAllProvider()),
        ChangeNotifierProvider(create: (_) => MusicProvider()),
        ChangeNotifierProvider(create: (_) => MusicDetailProvider()),
        ChangeNotifierProvider(create: (_) => NotificationProvider()),
        ChangeNotifierProvider(create: (_) => RewardProvider()),
        ChangeNotifierProvider(create: (_) => DownLoadProvider()),
      ],
      child: const MyApp(),
    ),
  );
  SystemChrome.setPreferredOrientations([
    DeviceOrientation.portraitUp,
    DeviceOrientation.landscapeLeft,
    DeviceOrientation.landscapeRight,
  ]);
}

final RouteObserver<ModalRoute<void>> routeObserver =
    RouteObserver<ModalRoute<void>>();
final GlobalKey<NavigatorState> navigatorKey = GlobalKey<NavigatorState>();

class MyApp extends StatefulWidget {
  const MyApp({super.key});

  @override
  State<MyApp> createState() => _MyAppState();
}

class _MyAppState extends State<MyApp> {
  SharedPre sharedPre = SharedPre();

  @override
  void initState() {
    // if (!kIsWeb) Utils.enableScreenCapture();
    if (!kIsWeb) _getDeviceInfo();
    WidgetsBinding.instance.addPostFrameCallback((_) async {
      _getData();
    });
    musicManager = MusicManager(context);
    super.initState();
  }

  _getData() async {
    Constant.userID = await sharedPre.read('userid');
    printLog('Constant userID =====> ${Constant.userID}');

    /* Initialize Hive */
    if (!kIsWeb) {
      await Utils.initializeHiveBoxes();
    }
  }

  @override
  Widget build(BuildContext context) {
    return Shortcuts(
      shortcuts: <LogicalKeySet, Intent>{
        LogicalKeySet(LogicalKeyboardKey.select): const ActivateIntent(),
        LogicalKeySet(LogicalKeyboardKey.enter): const ActivateIntent(),
      },
      child: LocaleBuilder(
        builder: (locale) {
          if (kIsWeb) {
            return _buildForWeb(locale: locale);
          } else {
            return _buildForOther(locale: locale);
          }
        },
        // MaterialApp(
        //   navigatorKey: navigatorKey,
        //   debugShowCheckedModeBanner: false,
        //   navigatorObservers: [routeObserver],
        //   theme: ThemeData(
        //     primaryColor: yellow,
        //     primaryColorDark: colorPrimaryDark,
        //     primaryColorLight: primaryLight,
        //     scaffoldBackgroundColor: appBgColor,
        //   ).copyWith(
        //     scrollbarTheme: const ScrollbarThemeData().copyWith(
        //       thumbColor: WidgetStateProperty.all(white),
        //       trackVisibility: WidgetStateProperty.all(true),
        //       trackColor: WidgetStateProperty.all(transparentColor),
        //     ),
        //   ),
        //   title: Constant.appName,
        //   localizationsDelegates: Locales.delegates,
        //   supportedLocales: Locales.supportedLocales,
        //   locale: locale,
        //   localeResolutionCallback:
        //       (Locale? locale, Iterable<Locale> supportedLocales) {
        //     return locale;
        //   },
        //   builder: (context, child) {
        //     return ResponsiveBreakpoints.builder(
        //       child: child!,
        //       breakpoints: [
        //         const Breakpoint(start: 0, end: 360, name: MOBILE),
        //         const Breakpoint(start: 361, end: 800, name: TABLET),
        //         const Breakpoint(start: 801, end: 1000, name: DESKTOP),
        //         const Breakpoint(start: 1001, end: double.infinity, name: '4K'),
        //       ],
        //     );
        //   },
        //   home: (kIsWeb)
        //       ? const WebHome(
        //           pageName: 'home',
        //         )
        //       : const Splash(),
        //   scrollBehavior: const MaterialScrollBehavior().copyWith(
        //     dragDevices: {
        //       PointerDeviceKind.mouse,
        //       PointerDeviceKind.touch,
        //       PointerDeviceKind.stylus,
        //       PointerDeviceKind.unknown,
        //       PointerDeviceKind.trackpad
        //     },
        //   ),
        // ),
      ),
    );
  }

  Widget _buildForOther({required Locale? locale}) {
    return MaterialApp(
      navigatorKey: navigatorKey,
      debugShowCheckedModeBanner: false,
      navigatorObservers: [routeObserver],
      theme: ThemeData(
        primaryColor: yellow,
        primaryColorDark: colorPrimaryDark,
        primaryColorLight: primaryLight,
        scaffoldBackgroundColor: colorPrimary,
      ).copyWith(
        scrollbarTheme: const ScrollbarThemeData().copyWith(
          thumbColor: WidgetStateProperty.all(white),
          trackVisibility: WidgetStateProperty.all(true),
          trackColor: WidgetStateProperty.all(transparentColor),
        ),
      ),
      title: Constant.appName,
      localizationsDelegates: Locales.delegates,
      supportedLocales: Locales.supportedLocales,
      locale: locale,
      localeResolutionCallback:
          (Locale? locale, Iterable<Locale> supportedLocales) {
        return locale;
      },
      builder: (context, child) {
        return ResponsiveBreakpoints.builder(
          child: child!,
          breakpoints: [
            const Breakpoint(start: 0, end: 360, name: MOBILE),
            const Breakpoint(start: 361, end: 800, name: TABLET),
            const Breakpoint(start: 801, end: 1000, name: DESKTOP),
            const Breakpoint(start: 1001, end: double.infinity, name: '4K'),
          ],
        );
      },
      home: const Splash(),
      scrollBehavior: const MaterialScrollBehavior().copyWith(
        dragDevices: {
          PointerDeviceKind.mouse,
          PointerDeviceKind.touch,
          PointerDeviceKind.stylus,
          PointerDeviceKind.unknown,
          PointerDeviceKind.trackpad
        },
      ),
    );
  }

  Widget _buildForWeb({required Locale? locale}) {
    return MaterialApp.router(
      debugShowCheckedModeBanner: false,
      routerConfig: RoutesConfig().goRouter,
      theme: ThemeData(
        primaryColor: yellow,
        primaryColorDark: colorPrimaryDark,
        primaryColorLight: yellow,
        scaffoldBackgroundColor: colorPrimary,
        pageTransitionsTheme: PageTransitionsTheme(
          builders: kIsWeb
              ? {
                  for (final platform in TargetPlatform.values)
                    platform: const NoTransitionsBuilder(),
                }
              : const {
                  TargetPlatform.android: ZoomPageTransitionsBuilder(),
                  TargetPlatform.iOS: CupertinoPageTransitionsBuilder(),
                },
        ),
      ).copyWith(
        scrollbarTheme: const ScrollbarThemeData().copyWith(
          thumbColor: WidgetStateProperty.all(white),
          trackVisibility: WidgetStateProperty.all(true),
          trackColor: WidgetStateProperty.all(white.withOpacity(0.5)),
        ),
      ),
      title: Constant.appName,
      localizationsDelegates: Locales.delegates,
      supportedLocales: Locales.supportedLocales,
      locale: locale,
      localeResolutionCallback:
          (Locale? locale, Iterable<Locale> supportedLocales) {
        return locale;
      },
      builder: (context, child) {
        return ResponsiveBreakpoints.builder(
          child: child!,
          breakpoints: [
            const Breakpoint(start: 0, end: 360, name: MOBILE),
            const Breakpoint(start: 361, end: 800, name: TABLET),
            const Breakpoint(start: 801, end: 1000, name: DESKTOP),
            const Breakpoint(start: 1001, end: double.infinity, name: '4K'),
          ],
        );
      },
      scrollBehavior: const MaterialScrollBehavior().copyWith(
        dragDevices: {
          PointerDeviceKind.mouse,
          PointerDeviceKind.touch,
          PointerDeviceKind.stylus,
          PointerDeviceKind.unknown,
          PointerDeviceKind.trackpad
        },
      ),
    );
  }

  _getDeviceInfo() async {
    if (Platform.isAndroid) {
      DeviceInfoPlugin deviceInfo = DeviceInfoPlugin();
      AndroidDeviceInfo androidInfo = await deviceInfo.androidInfo;
      Constant.isTV =
          androidInfo.systemFeatures.contains('android.software.leanback');
      printLog("isTV =======================> ${Constant.isTV}");
    }
  }
}

class NoTransitionsBuilder extends PageTransitionsBuilder {
  const NoTransitionsBuilder();

  @override
  Widget buildTransitions<T>(
    PageRoute<T>? route,
    BuildContext? context,
    Animation<double> animation,
    Animation<double> secondaryAnimation,
    Widget? child,
  ) {
    return child!;
  }
}
